## Summary

Describe the change.

## Checklist

- [ ] I ran `ruff check aiogram_mcp tests examples`
- [ ] I ran `mypy aiogram_mcp`
- [ ] I ran `pytest -v`
- [ ] I updated tests if behavior changed
- [ ] I updated docs or examples if public behavior changed
- [ ] I updated `CHANGELOG.md` for user-visible changes
